@@ -22,7 +22,7 @@ use std::{
 use rand::{CryptoRng, Rng, RngCore};
 
 use snarkvm_algorithms::{SNARKError, SNARK};
-use snarkvm_fields::{PoseidonMDSField, PrimeField, ToConstraintField};
+use snarkvm_fields::{PrimeField, ToConstraintField};
 use snarkvm_gadgets::{
     bits::Boolean,
     nonnative::NonNativeFieldInputVar,
@@ -74,7 +74,7 @@ impl Debug for MarlinBound {
 /// The Marlin proof system.
 pub struct MarlinSNARK<
     F: PrimeField,
-    FSF: PrimeField + PoseidonMDSField,
+    FSF: PrimeField,
     PC: PolynomialCommitment<F>,
     FS: FiatShamirRng<F, FSF>,
     MC: MarlinMode,
@@ -93,7 +93,7 @@ pub struct MarlinSNARK<
 impl<TargetField, BaseField, PC, FS, MM, C, V> MarlinSNARK<TargetField, BaseField, PC, FS, MM, C, V>
 where
     TargetField: PrimeField,
-    BaseField: PrimeField + PoseidonMDSField,
+    BaseField: PrimeField,
     PC: PolynomialCommitment<TargetField>,
     FS: FiatShamirRng<TargetField, BaseField>,
     MM: MarlinMode,
@@ -163,7 +163,7 @@ where
 impl<TargetField, BaseField, PC, FS, MM, C, V> SNARK for MarlinSNARK<TargetField, BaseField, PC, FS, MM, C, V>
 where
     TargetField: PrimeField,
-    BaseField: PrimeField + PoseidonMDSField,
+    BaseField: PrimeField,
     PC: PolynomialCommitment<TargetField>,
     FS: FiatShamirRng<TargetField, BaseField>,
     MM: MarlinMode,
@@ -221,7 +221,7 @@ where
 pub struct MarlinSNARKGadget<F, FSF, PC, FS, MM, PCG, FSG>
 where
     F: PrimeField,
-    FSF: PrimeField + PoseidonMDSField,
+    FSF: PrimeField,
     PC: PolynomialCommitment<F>,
     FS: FiatShamirRng<F, FSF>,
     MM: MarlinMode,
@@ -242,7 +242,7 @@ impl<TargetField, BaseField, PC, FS, MM, PCG, FSG, C, V>
     for MarlinSNARKGadget<TargetField, BaseField, PC, FS, MM, PCG, FSG>
 where
     TargetField: PrimeField,
-    BaseField: PrimeField + PoseidonMDSField,
+    BaseField: PrimeField,
     PC: PolynomialCommitment<TargetField>,
     FS: FiatShamirRng<TargetField, BaseField>,
     MM: MarlinMode,
@@ -700,7 +700,7 @@ pub mod multiple_input_tests {
 
     pub struct VerifierCircuit<
         F: PrimeField,
-        ConstraintF: PrimeField + PoseidonMDSField,
+        ConstraintF: PrimeField,
         PC: PolynomialCommitment<F>,
         FS: FiatShamirRng<F, ConstraintF>,
         MM: MarlinMode,
@@ -725,7 +725,7 @@ pub mod multiple_input_tests {
 
     impl<
         F: PrimeField,
-        ConstraintF: PrimeField + PoseidonMDSField,
+        ConstraintF: PrimeField,
         PC: PolynomialCommitment<F>,
         FS: FiatShamirRng<F, ConstraintF>,
         MM: MarlinMode,
@@ -917,63 +917,4 @@ pub mod multiple_input_tests {
             );
         }
     }
-
-    #[test]
-    fn marlin_test_nested_snark() {
-        let mut rng = test_rng();
-
-        // Construct the circuit.
-
-        let a = Fr::rand(&mut rng);
-        let b = Fr::rand(&mut rng);
-        let mut c = a;
-        c.mul_assign(&b);
-
-        let circ = Circuit {
-            a: Some(a),
-            b: Some(b),
-            num_constraints: 100,
-            num_variables: 25,
-        };
-
-        // Generate the circuit parameters.
-
-        let (pk, vk) = TestSNARK::circuit_specific_setup(circ, &mut rng).unwrap();
-
-        // Test native proof and verification.
-
-        let proof = TestSNARK::prove(&pk, &circ, &mut rng).unwrap();
-
-        assert!(
-            TestSNARK::verify(&vk.clone().into(), &[c.clone(), c].to_vec(), &proof).unwrap(),
-            "The native verification check fails."
-        );
-
-        // Initialize constraint system.
-        let nested_circuit = VerifierCircuit::<Fr, Fq, PC, FS, MarlinRecursiveMode, PCGadget, FSG> {
-            c: c.clone(),
-            verifying_key: vk,
-            proof,
-            _f: PhantomData,
-            _fs: PhantomData,
-            _marlin_mode: PhantomData,
-            _pcg: PhantomData,
-            _fsg: PhantomData,
-        };
-
-        use snarkvm_algorithms::snark::groth16::Groth16;
-        type NestedSNARK =
-            Groth16<BW6_761, VerifierCircuit<Fr, Fq, PC, FS, MarlinRecursiveMode, PCGadget, FSG>, Vec<Fq>>;
-
-        let (nested_pk, nested_vk) = NestedSNARK::setup(&nested_circuit, &mut rng).unwrap();
-
-        // Test native proof and verification.
-
-        let nested_proof = NestedSNARK::prove(&nested_pk, &nested_circuit, &mut rng).unwrap();
-
-        assert!(
-            NestedSNARK::verify(&nested_vk.clone().into(), &vec![], &nested_proof).unwrap(),
-            "The native verification check fails."
-        );
-    }
 }
